==> doctorlink-design-system-1.1.6.tgz: package/es/Components/TextField/TextFieldComponents.js <==
import React from 'react';
import * as reset from '../reset';
import { BodyComponent } from '../Text/Body';
import { LinkComponent } from '../Link/Link';

export const Label = BodyComponent.extend`
  color: ${props => props.theme.textfield.labelColor};
  margin-bottom: 6px;
  font-weight: bold;
  padding: 0;
`;

export const Toggle = BodyComponent.extend`
  color: ${props => props.theme.text.link.color};
  cursor: pointer;
  text-decoration: underline;
  padding-left: 18px;
  padding-right: 18px;
`;

export const ErrorText = BodyComponent.extend`
  color: ${p => p.theme.textfield.error.color};
`;

export const Caption = BodyComponent.extend`
  padding: 0;
  margin-bottom: 6px;
`;

export const Link = LinkComponent.extend``;

export const TextInputContainer = reset.div`
  display: flex;
  height: ${p => p.theme.text.body.lineHeight + 30}px;
  border-width: 1px;
  border-style: solid;
  border-color: ${props => {
  if (props.disabled) {
    return props.theme.textfield.disabled.borderColor;
  }
  if (props.error) {
    return props.theme.textfield.error.borderColor;
  }
  if (props.isFocused) {
    return props.theme.textfield.focus.borderColor;
  }
  return props.theme.textfield.borderColor;
}};
  border-radius: 4px;
  background-color: ${props => props.theme.colors.white};
  &:hover {
    border-color:${props => {
  if (props.error || props.disabled || props.isFocused) return '';
  return props.theme.textfield.hover.borderColor;
}}
  }
`;

export const TextInput = reset.input.attrs({
  type: p => p.type || 'text'
})`
  font-family: ${p => p.theme.text.fontFamily};
  font-size: ${p => p.theme.text.body.fontSize}px;
  line-height: ${p => p.theme.text.body.lineHeight}px;
  padding-right: ${p => p.toggle && '50px'};
  outline: none;
  border: none;
  background: transparent;
  padding: 15px 18px;
  color: ${p => p.theme.text.body.color};
`;

export const TextFieldComponent = reset.div`
  padding: 18px 0;
`;

const TextField = props => React.createElement(TextFieldComponent, props);
export default TextField;

==> doctorlink-design-system-1.2.1.tgz: package/es/Components/TextField/TextFieldComponents.js <==
import React from 'react';
import * as reset from '../reset';
import { BodyComponent } from '../Text/Body';
import { LinkComponent } from '../Link/Link';

export const Label = BodyComponent.extend`
  color: ${props => props.theme.labelColor};
  margin-bottom: 6px;
  font-weight: bold;
  padding: 0;
`;

export const Toggle = BodyComponent.extend`
  color: ${props => props.theme.typography.link.color};
  cursor: pointer;
  text-decoration: underline;
  padding-left: 18px;
  padding-right: 18px;
`;

export const ErrorText = BodyComponent.extend`
  color: ${p => p.theme.error.color};
`;

export const Caption = BodyComponent.extend`
  padding: 0;
  margin-bottom: 6px;
`;

export const Link = LinkComponent.extend``;

export const TextInputContainer = reset.div`
  display: flex;
  height: ${p => p.theme.typography.body.lineHeight + 30}px;
  border-width: 1px;
  border-style: solid;
  border-color: ${props => {
  if (props.disabled) {
    return props.theme.disabled.borderColor;
  }
  if (props.error) {
    return props.theme.error.borderColor;
  }
  if (props.isFocused) {
    return props.theme.focus.borderColor;
  }
  return props.theme.borderColor;
}};
  border-radius: 4px;
  background-color: ${props => props.theme.colors.white};
  &:hover {
    border-color:${props => {
  if (props.error || props.disabled || props.isFocused) return '';
  return props.theme.hover.borderColor;
}}
  }
`;

export const TextInput = reset.input.attrs({
  type: p => p.type || 'text'
})`
  font-family: ${p => p.theme.typography.fontFamily};
  font-size: ${p => p.theme.typography.body.fontSize}px;
  line-height: ${p => p.theme.typography.body.lineHeight}px;
  padding-right: ${p => p.toggle && '50px'};
  outline: none;
  border: none;
  background: transparent;
  padding: 15px 18px;
  color: ${p => p.theme.typography.body.color};
`;

export const TextFieldComponent = reset.div`
  padding: 18px 0;
`;

const TextField = props => React.createElement(TextFieldComponent, props);
export default TextField;
